==================
pywe-event-message
==================

Wechat Event Message Module for Python.

Installation
============

::

    pip install pywe-event-message


Usage
=====

::

    from pywe_event_message import parse_eventkey


Method
======

::

    def parse_eventkey(eventkey, event='subscribe', key_cast_func=None):

